# Andrew Anderson's utils

session_protocol:
  Basic package. Contents protocol class (socket subclass), which is designed for safe client-server communications.

onion_dns (is not available yet):
  Resolves dns names through tor.